```
Usage: vcd gateway services nat reorder [OPTIONS] <gateway name> <nat rule id>

Options:
  --index <int>  index where NAT rule will be moved/shifted
  -h, --help     Show this message and exit.

```
